# Copyright © 2020-2022 Nick Bowler
#
# License GPLv2+: GNU General Public License version 2 or any later version.
# This is free software: you are free to change and redistribute it.
# There is NO WARRANTY, to the extent permitted by law.
#
# This is a modified version of the original ebuild from Gentoo GNU/Linux,
# covered by the following copyright and permission notice:
#
#   Copyright 1999-2020 Gentoo Authors
#   Distributed under the terms of the GNU General Public License v2
#
# The modifications are:
#
#   * Resurrect python2 version installable alongside newer version (2020-11)
#   * Avoid python eclasses as there is no more python2 support (2022-12)

EAPI=7

DESCRIPTION="Python bindings for the cairo library"
HOMEPAGE="https://www.cairographics.org/pycairo/ https://github.com/pygobject/pycairo"
SRC_URI="https://github.com/pygobject/${PN}/releases/download/v${PV}/${P}.tar.gz"

LICENSE="|| ( LGPL-2.1 MPL-1.1 )"
SLOT="2"
KEYWORDS="~alpha amd64 arm arm64 hppa ~ia64 ~mips ppc ppc64 s390 sparc x86 ~amd64-linux ~x86-linux ~ppc-macos ~x64-macos ~x86-macos"
IUSE="examples"

# Strong block on old pycairo w/ python2 support because the merge will
# otherwise not work properly due to replacing a directory with a file.

DEPEND=">=x11-libs/cairo-1.13.1[svg]
	!!dev-python/pycairo:0[python_targets_python2_7]"
RDEPEND="$DEPEND
	dev-lang/python:2.7[threads(+)]"
BDEPEND="dev-lang/python:2.7"

PATCHES=(
	"$FILESDIR/$P-no-setuptools.patch"
	"$FILESDIR/$PN-1.19.1-py39.patch"
)

src_compile () {
	python2.7 setup.py build || die
}

src_install () {
	default

	if use examples; then
		dodoc -r examples
	fi

	python2.7 setup.py install --skip-build --root="$D" || die
}
